<?php

namespace Phlaym\PhotoprismApi\Entities;

use Phlaym\PhotoprismApi\API\LoggerFactory;
use Psr\Log\LoggerInterface;

/** A PhotoPrism Album */
class Album
{
    /** @var string $uid Unique Id of the album */
    public string $uid = '';

    /** @var string $slug URL slug of the album */
    public string $slug = '';

    /** @var string $title Title of the album */
    public string $title = '';

    /** @var string|null $token Secret token of the album. Needs to be set by the API */
    public ?string $token = null;

    /** @var int $photoCount Number of photos in Album */
    public int $photoCount = 0;

    /** @var LoggerInterface $logger Logger object */
    private LoggerInterface $logger;

    /**
     * Creates a new album from the api response
     *
     * @param array $response Photoprism API response containing an album object
     *
     * @return void
     */
    public function __construct(
        array $response
    ) {
        $this->uid = $response['UID'];
        $this->slug = $response['Slug'];
        $this->title = $response['Title'];
        if (isset($response['PhotoCount'])) {
            $this->photoCount = $response['PhotoCount'];
        }
        $this->logger = LoggerFactory::create('Phlaym\PhotoprismApi.Album');
    }

    /**
     * Gets the URL path for this album.
     * Starts with a leading /
     * Returns null if the album's token is not set
     *
     * @return string|null
     */
    public function getUrlPath(): ?string
    {
        if (empty($this->token)) {
            return null;
        }
        return "/s/{$this->token}/{$this->slug}";
    }
}
